@@ -23,7 +23,7 @@ use web_sys::{Element, Node};
 /// Note: If Program is None, it is a dumb patch, meaning
 /// there is no event listener attached or changed
 pub fn patch<DSP, MSG>(
-    program: Option<&DSP>,
+    program: &DSP,
     root_node: &mut Node,
     old_closures: &mut ActiveClosure,
     focused_node: &mut Option<Node>,
@@ -44,7 +44,7 @@ where
 
 /// patch using the tree path traversal instead of node_idx
 pub fn patch_by_traversal_path<DSP, MSG>(
-    program: Option<&DSP>,
+    program: &DSP,
     root_node: &mut Node,
     old_closures: &mut ActiveClosure,
     focused_node: &mut Option<Node>,
@@ -54,13 +54,25 @@ where
     MSG: 'static,
     DSP: Clone + Dispatch<MSG> + 'static,
 {
+    #[cfg(feature = "with-measure")]
+    let t1 = crate::now();
+
     let nodes_to_find: Vec<(&[usize], Option<&&'static str>)> = patches
         .iter()
         .map(|patch| (patch.path(), patch.tag()))
         .collect();
+
     let mut active_closures = HashMap::new();
     let nodes_to_patch =
         find_all_nodes_by_path(root_node.clone(), &nodes_to_find);
+
+    #[cfg(feature = "with-measure")]
+    let t2 = {
+        let t2 = crate::now();
+        log::trace!("finding nodes to patch took: {}ms", t2 - t1);
+        t2
+    };
+
     for patch in patches.iter() {
         let patch_path = patch.path();
         if let Some(element) = nodes_to_patch.get(patch_path) {
@@ -77,6 +89,13 @@ where
             unreachable!("Getting here means we didn't find the element of next node that we are supposed to patch, patch_path: {:?} node_idx: {}", patch_path, patch.node_idx());
         }
     }
+
+    #[cfg(feature = "with-measure")]
+    let _t3 = {
+        let t3 = crate::now();
+        log::trace!("actual applying patch took: {}ms", t3 - t2);
+        t3
+    };
     Ok(active_closures)
 }
 
@@ -87,7 +106,7 @@ where
 /// Note: If Program is None, it is a dumb patch, meaning
 /// there is no event listener attached or changed
 pub fn patch_by_node_idx_traversal<DSP, MSG>(
-    program: Option<&DSP>,
+    program: &DSP,
     root_node: &mut Node,
     old_closures: &mut ActiveClosure,
     focused_node: &mut Option<Node>,
@@ -293,8 +312,6 @@ fn find_all_nodes_by_path(
 
 /// Get the "data-sauron-vdom-id" of all the desendent of this node including itself
 /// This is needed to free-up the closure that was attached ActiveClosure manually
-/// TODO: Make a test when an element is removed, all of it's descendant closure should also be
-/// removed as well.
 fn get_node_descendant_data_vdom_id(root_element: &Element) -> Vec<u32> {
     let mut data_vdom_id = vec![];
 
@@ -390,7 +407,7 @@ fn remove_event_listener_with_name(
 /// Note: a mutable root_node is passed here
 /// for the sole purpose of setting it when the a patch ReplaceNode at 0 is encountered.
 fn apply_patch_to_node<DSP, MSG>(
-    program: Option<&DSP>,
+    program: &DSP,
     root_node: &mut Node,
     node: &Node,
     old_closures: &mut ActiveClosure,
@@ -405,18 +422,18 @@ where
 
     match patch {
         Patch::InsertNode(InsertNode {
-            tag: _,
-            patch_path: _,
+            tag,
+            patch_path,
             node: for_insert,
         }) => {
             let element: &Element = node.unchecked_ref();
-            let created_node = CreatedNode::create_dom_node_opt::<DSP, MSG>(
+            let created_node = CreatedNode::create_dom_node::<DSP, MSG>(
                 program,
                 &for_insert,
                 focused_node,
             );
             let parent_node =
-                element.parent_node().expect("must have a parent node");
+                element.parent_node().unwrap_or_else(||panic!("must have a parent node, tag: {:?}, path: {:?}, for patch: {:#?}", tag, patch_path, for_insert));
             parent_node
                 .insert_before(&created_node.node, Some(element))
                 .expect("must remove target node");
@@ -471,14 +488,17 @@ where
             replacement,
         }) => {
             let element: &Element = node.unchecked_ref();
-            let created_node = CreatedNode::create_dom_node_opt::<DSP, MSG>(
+            // FIXME: performance bottleneck here
+            // Each element and it's descendant is created. Each call to dom to create the element
+            // has a cost of ~1ms due to bindings in wasm-bindgen, multiple call of 1000 elements can accumulate to 1s time.
+            //
+            // Possible fix: stringify and process the patch in plain javascript code.
+            // That way, all the code is done at once.
+            let created_node = CreatedNode::create_dom_node::<DSP, MSG>(
                 program,
                 replacement,
                 focused_node,
             );
-            if patch_path.node_idx == 0 {
-                *root_node = created_node.node.clone();
-            }
             if let Some(tag) = tag {
                 let target_tag = element.tag_name().to_lowercase();
                 if target_tag != **tag {
@@ -496,6 +516,13 @@ where
                 .replace_with_with_node_1(&created_node.node)
                 .expect("must replace node");
 
+            // if what we are replacing is a root node:
+            // we replace the root node here, so that's reference is updated
+            // to the newly created node
+            if patch_path.path == &[0] {
+                log::debug!("replacing root node..");
+                *root_node = created_node.node;
+            }
             Ok(created_node.closures)
         }
         Patch::RemoveNode(RemoveNode { .. }) => {
@@ -523,7 +550,7 @@ where
             let element: &Element = node.unchecked_ref();
             let mut active_closures = HashMap::new();
             for (_append_children_node_idx, new_node) in new_nodes.iter() {
-                let created_node = CreatedNode::create_dom_node_opt::<DSP, MSG>(
+                let created_node = CreatedNode::create_dom_node::<DSP, MSG>(
                     program,
                     &new_node,
                     focused_node,
