@@ -1,4 +1,3 @@
-use crate::map_msg::NodeMapMsg;
 use crate::{
     diff,
     dom::{
@@ -201,25 +200,6 @@ where
         .expect("Error in patching the dom");
         self.active_closures.extend(active_closures);
     }
-    /// map this DomUpdater such that the Node<MSG> will become Node<MSG2>
-    pub fn map_msg<F, MSG2>(self, func: F) -> DomUpdater<MSG2>
-    where
-        F: Fn(MSG) -> MSG2 + 'static,
-        MSG2: 'static,
-    {
-        let DomUpdater {
-            current_vdom,
-            root_node,
-            active_closures,
-            focused_node,
-        } = self;
-        DomUpdater {
-            current_vdom: current_vdom.map_msg(func),
-            root_node,
-            active_closures,
-            focused_node,
-        }
-    }
 
     /// Return the root node of your application, the highest ancestor of all other nodes in
     /// your real DOM tree.
