@@ -1,6 +1,14 @@
 use crate::prelude::Value;
 use std::fmt;
 
+/// Creat a style attribute
+#[macro_export]
+macro_rules! style {
+    ( $($arg: tt)* ) => {
+        attr("style", $crate::jss::style!{$($arg)*})
+    };
+}
+
 /// css styles
 /// style can be converted into an attribute
 #[derive(Debug, Clone, PartialEq)]
