@@ -48,6 +48,13 @@ pub trait Render {
         self.render_compressed(&mut buffer).expect("must render");
         buffer
     }
+
+    /// render to string with nice indention
+    fn render_to_string_pretty(&self) -> String {
+        let mut buffer = String::new();
+        self.render(&mut buffer).expect("must render");
+        buffer
+    }
 }
 
 impl<MSG> Render for Node<MSG> {
@@ -62,7 +69,9 @@ impl<MSG> Render for Node<MSG> {
             Node::Element(element) => {
                 element.render_with_indent(buffer, indent, node_idx, compressed)
             }
-            Node::Text(text) => write!(buffer, "{}", text.text),
+            Node::Text(text) => {
+                write!(buffer, "{}", &text.text)
+            }
         }
     }
 }
